==> spectral_recovery-0.2.0b2.tar.gz: spectral_recovery-0.2.0b2/README.md <==
# (pre-release) spectral-recovery: spectral recovery analysis of forested ecosystems

[![PyPI version](https://badge.fury.io/py/spectral-recovery.svg)](https://badge.fury.io/py/spectral-recovery) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

---
Github: [https://github.com/PEOPLE-ER/Spectral-Recovery/](https://github.com/PEOPLE-ER/Spectral-Recovery/)

Documentation: [https://people-er.github.io/Spectral-Recovery/](https://people-er.github.io/Spectral-Recovery/)

PyPi: [https://pypi.org/project/spectral-recovery/](https://pypi.org/project/spectral-recovery/)

Interactive Notebooks: Coming soon!

---
## Overview

**spectral-recovery** is an open-source project and Python package that provides computationally simple, centralized, and reproducible methods for performing [spectral recovery analysis](https://people-er.github.io/Spectral-Recovery/about/#13-looking-at-recovery-trajectories) of forests using satellite imagery.

The package provides straight-forward interfaces to help coordinate the many moving parts of spectral recovery analysis. Users provide restoration site locations, restoration dates, and annual composites of spectral data, while spectral-recovery handles computing the spectral indices, recovery targets, recovery metrics, and more!

The package aims, through both software and supplementary documentation, to make spectral recovery analysis more approachable, encouraging the use and adoption of well-founded remote sensing techniques to aid [Ecosystem Restoration](https://people-er.github.io/Spectral-Recovery/about/#11-ecosystem-restoration) research and projects.

## Installation

```{bash}
pip install spectral-recovery
```

## Documentation

- View background information, static tutorials, and API references in our [project documentation.](https://people-er.github.io/Spectral-Recovery/)
- Try out an interactive notebook (Coming soon!)

## Contributing

- Report bugs, suggest features, and see what others are saying on our [GitHub Issues](https://github.com/PEOPLE-ER/Spectral-Recovery/issues) page.
- Start discussions about the tool on our [discussion page](https://github.com/PEOPLE-ER/Spectral-Recovery/discussions).
- Want to contribute code? See our [CONTRIBUTING](https://github.com/PEOPLE-ER/Spectral-Recovery/blob/main/CONTRIBUTING.md) document for more information.

## How to Cite

When using this tool in your work we ask that you please cite the Spectral_Recovery tool as follows:

"Spectral Recovery method developed in the PEOPLE-ER Project, managed by Hatfield Consultants, and financed by the European Space Agency."

## License

Copyright 2023 Hatfield Consultants LLP

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

[http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

==> spectral_recovery-0.4.0.tar.gz: spectral_recovery-0.4.0/README.md <==
# (pre-release) spectral-recovery: spectral recovery analysis of forested ecosystems

[![PyPI version](https://badge.fury.io/py/spectral-recovery.svg)](https://badge.fury.io/py/spectral-recovery) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/PEOPLE-ER/Spectral-Recovery/HEAD?labpath=docs%2Fnotebooks%2F)


---
Github: [https://github.com/PEOPLE-ER/Spectral-Recovery/](https://github.com/PEOPLE-ER/Spectral-Recovery/)

Documentation: [https://people-er.github.io/Spectral-Recovery/](https://people-er.github.io/Spectral-Recovery/)

PyPi: [https://pypi.org/project/spectral-recovery/](https://pypi.org/project/spectral-recovery/)

Interactive Notebooks (Binder): [https://mybinder.org/v2/gh/PEOPLE-ER/Spectral-Recovery/HEAD?labpath=docs%2Fnotebooks%2F](https://mybinder.org/v2/gh/PEOPLE-ER/Spectral-Recovery/HEAD?labpath=docs%2Fnotebooks%2F)

---
## Overview

**spectral-recovery** is an open-source project and Python package that provides computationally simple, centralized, and reproducible methods for performing [spectral recovery analysis](https://people-er.github.io/Spectral-Recovery/about/#13-looking-at-recovery-trajectories) of forests using satellite imagery.

The package provides straight-forward interfaces to help coordinate the many moving parts of spectral recovery analysis. Users provide restoration site locations, restoration dates, and annual composites of spectral data, while spectral-recovery handles computing the spectral indices, recovery targets, recovery metrics, and more!

The package aims, through both software and supplementary documentation, to make spectral recovery analysis more approachable, encouraging the use and adoption of well-founded remote sensing techniques to aid [Ecosystem Restoration](https://people-er.github.io/Spectral-Recovery/about/#11-ecosystem-restoration) research and projects.

## Installation

```{bash}
pip install spectral-recovery
```

## Documentation

- View background information, static tutorials, and API references in our [project documentation.](https://people-er.github.io/Spectral-Recovery/)
- Try out an interactive notebook: [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/PEOPLE-ER/Spectral-Recovery/HEAD?labpath=docs%2Fnotebooks%2F)

## Contributing

- Report bugs, suggest features, and see what others are saying on our [GitHub Issues](https://github.com/PEOPLE-ER/Spectral-Recovery/issues) page.
- Start discussions about the tool on our [discussion page](https://github.com/PEOPLE-ER/Spectral-Recovery/discussions).
- Want to contribute code? See our [CONTRIBUTING](https://github.com/PEOPLE-ER/Spectral-Recovery/blob/main/CONTRIBUTING.md) document for more information.

## How to Cite

When using this tool in your work we ask that you please cite the Spectral_Recovery tool as follows:

"Spectral Recovery method developed in the PEOPLE-ER Project, managed by Hatfield Consultants, and financed by the European Space Agency."

## License

Copyright 2023 Hatfield Consultants LLP

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

[http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
